/*
  Wemos D1 mini/NodeMCU 1.0
  chip ESP-8266
  Jan Havlík, 7/2018
*/

#include <ESP8266WiFi.h>
#include <ESP8266WebServer.h>

// vytvoreni objektu weboveho serveru
ESP8266WebServer server(80);

// Prihlasovaci udaje k Wi-Fi
const char ssid[] = "tady_je_treba_vyplnit_jmeno_site";
const char heslo[] = "tady_je_treba_vyplnit_heslo";

// HTML hlavicka a paticka
PROGMEM const char html_hlavicka[] = "<!DOCTYPE html><html><head><title>Meteostanice</title><meta http-equiv=\"refresh\" content=\"70\"><style>html,body{font-family:'Segoe UI',Tahoma,Geneva,Verdana,sans-serif;margin:0;padding:0;display:flex;justify-content:center;align-items:center;width:100%;height:100%;overflow:hidden;background-color:black;}div{font-size:10vw;color:grey;resize:none;overflow:auto;}.value{color:white;font-weight:bolder;}</style></head><body><div>";
PROGMEM const char html_paticka[] = "</div></body>";

// deklarace promennych
unsigned long posledniObnova = 0;
unsigned long serverStart = 0;
unsigned long serverOn = 0;

void setup() {
  // spusteni seriove linky
  Serial.begin(9600);

  Serial.println("===================================");
  Serial.println("=== Wedos D1 Mini / NodeMCU 1.0 ===");
  Serial.println("===================================");
  
  // jmeno zarizeni v siti
  WiFi.hostname("webserver");
  // rezim Wi-Fi (sta = station)
  WiFi.mode(WIFI_STA);
  // zahajeni pripojovani
  WiFi.begin(ssid, heslo);
  Serial.print("Pripojuji se k Wi-Fi siti ");
  Serial.print(ssid);
  Serial.print(" ");
  // dokud se zarizeni nepripoji, vypisuji se do seriove linky tecky
  while (WiFi.status() != WL_CONNECTED) {
    Serial.print(".");
    delay(500);
  }
  Serial.println();

  // vypis do seriove linky pridelenou IP adresu
  Serial.print("Meteostanice ma IP adresu ");
  Serial.println(WiFi.localIP());

  /*
    Nastaveni weboveho serveru. Zareaguje, pokud zachyti pozadavek GET /,
    tedy pozadavek na korenovy adresar. Stejne tak bych mohl nastavit
    reakce na fiktivny stranky, treba server.on("/index.html" a tak dale.
  */
  server.on("/", []() {
//    // Ziskej parametr URL jmenem api, tedy /?api=...
//    String api = server.arg("api");
//    // Preved jej na mala pismena
//    api.toLowerCase();
//    /*
//      Pokud URL parametr obsahuje text 'json',
//      posli klientovi HTTP kod 200 a JSON s hodnotami ze senzoru
//      a vypis do seriove linky IP adresu klienta
//    */
//    if (api == "json") {
////       server.send(200, "application/json", "{\"tlak\":" + String(tlak, 2) + ",\"teplota\":" + String(teplota1, 2) + ",\"vlhkost\":" + String(vlhkost) + "}");
////       Serial << "HTTP GET: Klient si stahl JSON data" << endl << endl;
//    }
//    /*
//      Pokud URL parametr obsahuje neco jineho, nebo
//      neexistuje, posli klientovi HTTP kod 200 a HTML stranku
//    */
//    else {
//       server.send(200, "text/html", String(html_hlavicka) + "Teplota: <span class=\"value\">" + String(teplota1, 2) + " &#x00B0;C</span><br/>Tlak: <span class=\"value\">" + String(tlak, 2) + " hPa</span><br/>Vlhkost: <span class=\"value\">" + String(vlhkost) + " %</span>" + String(html_paticka));
//       Serial << "HTTP GET: Klient si stahl HTML stranku" << endl << endl;
       server.send(200, "text/html", String(html_hlavicka) + "Server bezi jiz " + String(serverOn/1000) + " s" + String(html_paticka));
       Serial.println("HTTP GET: Klient si stahl HTML stranku");    
//    }
  });

  // spusteni weboveho serveru
  server.begin();
  Serial.println("Webovy sever je spusteny a ceka!");
  serverStart = millis(); //ulozeni casu, kdy byl server spusten
}

void loop() {
  // Zpracuj pozadavky weboveho serveru
  server.handleClient();
  /*
    kazdou sekundu proved nacteni hodnot se sensoru nebo jiny podobny krok
    nelze pouzit delay(1000), protoze by se na celou dobu trvani delay()
    zastavil cely program, a kdyby v tuto chvili nekdo
    navstivil server, ten by na pozadavek zareagoval az uplynuti case nastaveneho v delay()

    funkci ziskejHodnoty take bylo mozne zavolat az pri
    pozadavku na webovy server, takto ale alze prubezne zaznamenavat
    treba rekordni hodnoty apod.
  */
  if ((millis() - posledniObnova) > 1000) {
    ziskejHodnoty();
    posledniObnova = millis();
  }
}

// funkce pro precteni hodnot ze senzoru do promennych apod.
void ziskejHodnoty() {
  serverOn = millis() - serverStart;
}
